"""Модуль настройки приложения email auth remote"""

from django.apps import AppConfig


class EmailAuthRemoteConfig(AppConfig):
    """Настройка приложения email auth remote"""

    default_auto_field = "django.db.models.BigAutoField"
    name = "email_auth_remote"
